/// <reference types="node" />
/// <reference types="node" />
import { ExecutionContext } from '@nestjs/common';
import { BeginParams, Session, Shopify } from '@shopify/shopify-api';
import { IncomingMessage, ServerResponse } from 'http';
type OAuthParams = Omit<BeginParams, 'rawRequest' | 'rawResponse'>;
export declare abstract class ShopifyHttpAdapter<RequestType = unknown, ResponseType = unknown> {
    protected readonly shopifyApi: Shopify;
    constructor(shopifyApi: Shopify);
    beginAuth(req: RequestType, res: ResponseType, params: OAuthParams): Promise<any>;
    beginCallback(req: RequestType, res: ResponseType): Promise<import("@shopify/shopify-api/dist/ts/lib/auth/oauth/oauth").CallbackResponse<any>>;
    getCurrentId(context: ExecutionContext, isOnline: boolean): Promise<string | undefined>;
    graphqlProxy(req: RequestType, res: ResponseType, session: Session): Promise<unknown>;
    getHeader(req: RequestType, headerName: string): string | string[] | undefined;
    getHeaderFromExecutionContext(context: ExecutionContext, headerName: string): string | string[] | undefined;
    getHeaders(req: RequestType): Record<string, string | string[] | undefined>;
    getHeadersFromExecutionContext(context: ExecutionContext): Record<string, string | string[] | undefined>;
    setHeaders(res: ResponseType, headers: Record<string, string | string[]>): void;
    getQueryParamFromExecutionContext(context: ExecutionContext, queryName: string): string | string[] | undefined;
    getQueryParam(req: RequestType, queryName: string): unknown;
    getQueryParamsFromExecutionContext<Query = Record<string, string | string[] | undefined>>(context: ExecutionContext): Query;
    getQueryParams<Query = Record<string, string | string[] | undefined>>(req: RequestType): Query;
    getRawBodyFromExecutionContext(context: ExecutionContext): Buffer | undefined;
    getRawBody(req: RequestType): Buffer | undefined;
    protected abstract setHeader(response: ResponseType, header: string, value: string | string[]): void;
    protected abstract extractHeaders(request: RequestType): Record<string, string | string[] | undefined>;
    protected abstract extractQueryParams<Query = Record<string, unknown>>(req: RequestType): Query;
    getRawRequest(req: RequestType): IncomingMessage;
    getRawResponse(res: ResponseType): ServerResponse;
    private getRequest;
    private getResponse;
    private getBody;
}
export {};
