"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShopifyHttpAdapter = void 0;
const tslib_1 = require("tslib");
class ShopifyHttpAdapter {
    constructor(shopifyApi) {
        this.shopifyApi = shopifyApi;
    }
    beginAuth(req, res, params) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.shopifyApi.auth.begin(Object.assign(Object.assign({}, params), { rawRequest: this.getRawRequest(req), rawResponse: this.getRawResponse(res) }));
        });
    }
    beginCallback(req, res) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.shopifyApi.auth.callback({
                rawRequest: this.getRawRequest(req),
                rawResponse: this.getRawResponse(res),
            });
        });
    }
    getCurrentId(context, isOnline) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const request = this.getRequest(context);
            const response = this.getResponse(context);
            return this.shopifyApi.session.getCurrentId({
                rawRequest: this.getRawRequest(request),
                rawResponse: this.getRawResponse(response),
                isOnline,
            });
        });
    }
    graphqlProxy(req, res, session) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { body, headers } = yield this.shopifyApi.clients.graphqlProxy({
                rawBody: this.getBody(req),
                session,
            });
            delete headers['Content-Encoding'];
            this.setHeaders(res, headers);
            return body;
        });
    }
    getHeader(req, headerName) {
        const headers = this.extractHeaders(req);
        return headers[headerName];
    }
    getHeaderFromExecutionContext(context, headerName) {
        const headers = this.getHeadersFromExecutionContext(context);
        return headers[headerName];
    }
    getHeaders(req) {
        return this.extractHeaders(req);
    }
    getHeadersFromExecutionContext(context) {
        const request = this.getRequest(context);
        return this.extractHeaders(request);
    }
    setHeaders(res, headers) {
        Object.entries(headers).forEach(([header, value]) => {
            this.setHeader(res, header, value);
        });
    }
    getQueryParamFromExecutionContext(context, queryName) {
        return this.getQueryParamsFromExecutionContext(context)[queryName];
    }
    getQueryParam(req, queryName) {
        return this.extractQueryParams(req)[queryName];
    }
    getQueryParamsFromExecutionContext(context) {
        const request = this.getRequest(context);
        return this.extractQueryParams(request);
    }
    getQueryParams(req) {
        return this.extractQueryParams(req);
    }
    getRawBodyFromExecutionContext(context) {
        const request = this.getRequest(context);
        return request.rawBody;
    }
    getRawBody(req) {
        return req.rawBody;
    }
    getRawRequest(req) {
        return req;
    }
    getRawResponse(res) {
        return res;
    }
    getRequest(context) {
        return context.switchToHttp().getRequest();
    }
    getResponse(context) {
        return context.switchToHttp().getResponse();
    }
    getBody(req) {
        return req.body;
    }
}
exports.ShopifyHttpAdapter = ShopifyHttpAdapter;
//# sourceMappingURL=http.adapter.js.map